@@ -15,4 +15,5 @@
 #
 # ##### END GPL LICENSE BLOCK #####
 
-a =1
\ No newline at end of file
+from .video import Video
+from . import shapes
